;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tron-legacy-theme" "20260610.1908"
  "An original retro-futuristic theme inspired by Tron: Legacy."
  ()
  :url "https://github.com/ianpan870102/tron-legacy-emacs-theme"
  :commit "fab4946d6266f73d5ec25660f67bd186dc44d426"
  :revdesc "fab4946d6266")
